summaryrefslogtreecommitdiffstats
path: root/drivers/gpu/drm/i915/intel_gvt.c
diff options
context:
space:
mode:
authorJanusz Krzysztofik <janusz.krzysztofik@linux.intel.com>2019-07-12 13:24:29 +0200
committerChris Wilson <chris@chris-wilson.co.uk>2019-07-12 13:05:08 +0100
commit78dae1ac35dd0c50d0f118e886b1f466cb9311fe (patch)
tree8d353551893495d0d426a607d1fa1d7f3e2a0552 /drivers/gpu/drm/i915/intel_gvt.c
parent3b58a94551368924d8a49baa349bc7694fbd7ddd (diff)
downloadlinux-stable-78dae1ac35dd0c50d0f118e886b1f466cb9311fe.tar.gz
linux-stable-78dae1ac35dd0c50d0f118e886b1f466cb9311fe.tar.bz2
linux-stable-78dae1ac35dd0c50d0f118e886b1f466cb9311fe.zip
drm/i915: Propagate "_remove" function name suffix down
Similar to the "_release" case, consistently replace mixed "_cleanup"/"_fini"/"_fini_hw" components found in names of functions called from i915_driver_remove() with "_remove" or "_driver_remove" suffixes for better code readability. Signed-off-by: Janusz Krzysztofik <janusz.krzysztofik@linux.intel.com> Reviewed-by: Chris Wilson <chris@chris-wilson.co.uk> Reviewed-by: Joonas Lahtinen <joonas.lahtinen@linux.intel.com> Signed-off-by: Chris Wilson <chris@chris-wilson.co.uk> Link: https://patchwork.freedesktop.org/patch/msgid/20190712112429.740-6-janusz.krzysztofik@linux.intel.com
Diffstat (limited to 'drivers/gpu/drm/i915/intel_gvt.c')
-rw-r--r--drivers/gpu/drm/i915/intel_gvt.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/drivers/gpu/drm/i915/intel_gvt.c b/drivers/gpu/drm/i915/intel_gvt.c
index 842ee26effd4..c66b2d8a6219 100644
--- a/drivers/gpu/drm/i915/intel_gvt.c
+++ b/drivers/gpu/drm/i915/intel_gvt.c
@@ -122,13 +122,14 @@ bail:
}
/**
* intel_gvt_cleanup - cleanup GVT components when i915 driver is unloading
* @dev_priv: drm i915 private *
*
* This function is called at the i915 driver unloading stage, to shutdown
* GVT components and release the related resources.
*/
-void intel_gvt_cleanup(struct drm_i915_private *dev_priv)
+void intel_gvt_driver_remove(struct drm_i915_private *dev_priv)
{
if (!intel_gvt_active(dev_priv))
return;
@@ -122,13 +122,14 @@ bail:
}
/**
- * intel_gvt_cleanup - cleanup GVT components when i915 driver is unloading
+ * intel_gvt_driver_remove - cleanup GVT components when i915 driver is
+ * unbinding
* @dev_priv: drm i915 private *
*